﻿Imports System.Xml
Imports System
Imports System.IO
Public Class PlugimPARReader
    Private _XDoc As New XmlDocument
    ''' <summary>
    ''' Read the plug im ! parameter file
    ''' </summary>
    ''' <returns>true if success</returns>
    ''' <remarks></remarks>
    Public Function ReadParFile() As Integer
        Dim fn, FuncName As String
        fn = Environment.GetCommandLineArgs(0)
        FuncName = Path.GetFileNameWithoutExtension(fn)
        fn = fn.Substring(0, fn.LastIndexOf("\"))
        fn = fn + "\" + FuncName + "PAR.xml"
        If Not (File.Exists(fn)) Then
            Return -1
        End If
        Try
            _XDoc.Load(fn)
        Catch ex As XmlException
            Return -2
        End Try
        Return 0
    End Function
    ''' <summary>
    ''' Get the node list associated to a tag name
    ''' </summary>
    ''' <param name="TagName">Name of the tag</param>
    ''' <returns>List of xml nodes containing the tag</returns>
    ''' <remarks></remarks>
    Private Function GetTag(ByVal TagName As String) As XmlNodeList
        Dim Tag As XmlNodeList = Nothing
        Try
            Tag = _XDoc.GetElementsByTagName(TagName)
        Catch ex As System.Xml.XmlException

        End Try
        Return Tag
    End Function
    ''' <summary>
    ''' Get an attribute of a xml node 
    ''' </summary>
    ''' <param name="Elem">Xml node</param>
    ''' <param name="AttributeName">Name of the attribute</param>
    ''' <returns></returns>
    ''' <remarks></remarks>
    Private Function GetAttribute(ByVal Elem As XmlNode, ByVal AttributeName As String) As String
        Dim Value As String = ""
        Try
            If Not (Elem.Attributes(AttributeName) Is Nothing) Then
                Value = Elem.Attributes(AttributeName).Value.ToString
            End If
        Catch ex As System.NullReferenceException

        End Try
        Return Value
    End Function
    ''' <summary>
    ''' Convert a string to an Int32 independantly of number syntax 
    ''' </summary>
    ''' <param name="str">String to convert</param>
    ''' <returns>Integer value meant by str</returns>
    ''' <remarks>return 0 if conversion is not possible</remarks>
    Private Function GetIntFromStr(ByVal str As String) As Int32
        Dim ibuf As Int32 = 0
        Dim ok As Boolean = Int32.TryParse(str, ibuf)
        If Not (ok) Then
            ok = Int32.TryParse(str, System.Globalization.NumberStyles.Any, System.Globalization.CultureInfo.CreateSpecificCulture("fr-FR"), ibuf)
        End If
        If Not (ok) Then
            ok = Int32.TryParse(str, System.Globalization.NumberStyles.Any, System.Globalization.CultureInfo.CreateSpecificCulture("en-EN"), ibuf)
        End If
        Return ibuf
    End Function
    ''' <summary>
    ''' Convert a string to a double independantly of number syntax
    ''' </summary>
    ''' <param name="str">String to convert</param>
    ''' <returns>Double value meant by str</returns>
    ''' <remarks>Returns 0.0 if conversion is not possible</remarks>
    Private Function GetDoubleFromStr(ByVal str As String)
        Dim dbuf As Double = 0.0
        Dim ok As Boolean = Double.TryParse(str, dbuf)
        If Not (ok) Then
            ok = Double.TryParse(str, System.Globalization.NumberStyles.Any, System.Globalization.CultureInfo.CreateSpecificCulture("fr-FR"), dbuf)
        End If
        If Not (ok) Then
            ok = Double.TryParse(str, System.Globalization.NumberStyles.Any, System.Globalization.CultureInfo.CreateSpecificCulture("en-EN"), dbuf)
        End If
        Return dbuf
    End Function
    ''' <summary>
    ''' Get a string value from a tag
    ''' </summary>
    ''' <param name="TagName">Tag name</param>
    ''' <returns>Value associated with the tag</returns>
    ''' <remarks>Returns the first occurence of the value attribute associated to the tag</remarks>
    Public Function GetStrFromTag(ByVal TagName As String) As String
        Dim AttributeName As String = "Value"
        Return GetAttribute(GetTag(TagName)(0), AttributeName)
    End Function
    ''' <summary>
    ''' Get an integer from a tag
    ''' </summary>
    ''' <param name="TagName">Tag name</param>
    ''' <returns>Value associated with the tag</returns>
    ''' <remarks>Returns the first occurence of the value attribute associated to the tag</remarks>
    Public Function GetIntFromTag(ByVal TagName As String) As Int32
        Return GetIntFromStr(GetStrFromTag(TagName))
    End Function
    ''' <summary>
    ''' Get a double from a tag
    ''' </summary>
    ''' <param name="TagName">Tag name</param>
    ''' <returns>Value associated with the tag</returns>
    ''' <remarks>Returns the first occurence of the value attribute associated to the tag</remarks>
    Public Function GetDoubleFromTag(ByVal TagName As String) As Double
        Return GetDoubleFromStr(GetStrFromTag(TagName))
    End Function
    ''' <summary>
    ''' Get a boolean from a tag
    ''' </summary>
    ''' <param name="TagName">Tag name</param>
    ''' <returns>Value associated with the tag</returns>
    ''' <remarks>Returns the first occurence of the value attribute associated to the tag</remarks>
    Public Function GetBoolFromTag(ByVal TagName As String) As Boolean
        Dim strret As String
        strret = GetStrFromTag(TagName)
        If strret = "true" Then
            Return True
        Else
            Return False
        End If
    End Function
    ''' <summary>
    ''' Get input file name
    ''' </summary>
    ''' <returns>Input file name</returns>
    ''' <remarks></remarks>
    Public Function GetINFile() As String
        Return GetStrFromTag("IN")
    End Function
    ''' <summary>
    ''' Get output file name
    ''' </summary>
    ''' <returns>Output file name</returns>
    ''' <remarks></remarks>
    Public Function GetOUTFile() As String
        Return GetStrFromTag("OUT")
    End Function
    ''' <summary>
    ''' Get preview file name
    ''' </summary>
    ''' <returns>Preview file name</returns>
    ''' <remarks></remarks>
    Public Function GetPREVFile() As String
        Return GetStrFromTag("OUTPREV")
    End Function
    ''' <summary>
    ''' Get the export file name
    ''' </summary>
    ''' <returns>Export file name</returns>
    ''' <remarks></remarks>
    Public Function GetExportFile() As String
        Return GetStrFromTag("Export")
    End Function
End Class
